==> nextcloud-app-tasks-0.9.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/sl.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Naloge",
    "Due yesterday" : "Preteklo včeraj",
    "Due today" : "Preteče danes",
    "Due tomorrow" : "Preteče jutri",
    "Due on" : "Preteče",
    "Started yesterday" : "Začeto včeraj",
    "Starts today" : "Začne se danes",
    "Starts tomorrow" : "Začne se jutri",
    "Started on" : "Začeto",
    "Starts on" : "Začne se",
    "[Remind me yesterday at ]HH:mm" : "[Opomni me včeraj ob ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Opomni me danes ob ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Opomni me jutri ob ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Opomni me ]DD, MMM YYYY,[ ob ]HH:mm",
    "Yesterday" : "Včeraj",
    "Today" : "Danes",
    "Tomorrow" : "Jutri",
    "in %s" : "v %s",
    "%s ago" : "pred %s",
    "seconds" : "sekund",
    "a minute" : "minuta",
    "%d minutes" : "%d minut",
    "an hour" : "ura",
    "%d hours" : "%d ur",
    "a day" : "dan",
    "%d days" : "%d dni",
    "a month" : "mesec",
    "%d months" : "%d mesecev",
    "a year" : "leto",
    "%d years" : "%d let",
    "week" : "teden",
    "weeks" : "tednov",
    "day" : "dan",
    "days" : "dni",
    "hour" : "ura",
    "hours" : "ur",
    "minute" : "minuta",
    "minutes" : "minut",
    "second" : "drugi",
    "before beginning" : "pred začetkom",
    "after beginning" : "po začetku",
    "before end" : "pred koncem",
    "after end" : "po koncu",
    "Comment" : "Opomba",
    "Add a comment" : "Dodaj opombo",
    "This will delete the Calendar \"%s\" and all of its entries." : "Izbrisan bo koledar \"%s\" in vsi vpisani vnosi.",
    "The name \"%s\" is already used." : "Ime \"%s\" je že v uporabi.",
    "An empty name is not allowed." : "Prazno polje imena ni dovoljeno.",
    "Hidden" : "Skrito",
    "Visible" : "Vidno",
    "Automatic" : "Samodejno",
    "Sunday" : "nedelja",
    "Monday" : "ponedeljek",
    "Tuesday" : "torek",
    "Wednesday" : "sreda",
    "Thursday" : "četrtek",
    "Friday" : "petek",
    "Saturday" : "sobota",
    "Add an important item in \"%s\"..." : "Dodaj opomnik v \"%s\" ...",
    "Add an item due today in \"%s\"..." : "Dodaj opomnik, ki poteče danes v \"%s\" ...",
    "Add an item in \"%s\"..." : "Dodaj predmet v \"%s\" ...",
    "Add a current item in \"%s\"..." : "Dodaj trenutni predmet v \"%s\" ...",
    "Add a subtask to \"%s\"..." : "Dodaj podrejeno nalogo \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n končana naloga","%n končani nalogi","%n končane naloge","%n končanih nalog"],
    "Hours" : "Ure",
    "Minutes" : "Minute",
    "Set due date" : "Nastavi datum preteka",
    "%s %% completed" : "%s %% končano",
    "priority %s: " : "prednost %s: ",
    "high" : "visoka",
    "medium" : "srednja",
    "low" : "nizka",
    "no priority assigned" : "prednost ni določena",
    "Remind me" : "Opomni me",
    "at the end" : "na koncu",
    "at the beginning" : "na začetku",
    "Set start date" : "Nastavi datum začetka",
    "{calendar} shared by {owner}" : "{calendar} je objavila oseba {owner}",
    "Unnamed" : "Neimenovano",
    "Important" : "Pomembno",
    "Week" : "Teden",
    "All" : "Vsi",
    "Current" : "Trenutno",
    "Completed" : "Končano",
    "Delete" : "Izbriši",
    "Cancel" : "Prekliči",
    "Edit" : "Uredi",
    "Link" : "Povezava",
    "Download" : "Prejmi",
    "Save" : "Shrani",
    "Add List..." : "Dodaj seznam ...",
    "New List" : "Nov seznam",
    "Settings" : "Nastavitve",
    "Start of week" : "Začetek tedna",
    "Visibility of Smart Collections" : "Vidnost pametnih zbirk",
    "Change sort order" : "Spremeni vrstni red razvrščanja",
    "Default" : "Privzeto",
    "Due date" : "Datum zapadlosti",
    "Start date" : "Datum začetka",
    "Priority" : "Prednost",
    "Alphabetically" : "Abecedno",
    "Manually" : "Ročno",
    "Load remaining completed tasks." : "Naloži preostale končane naloge.",
    "(New category)" : "(nova kategorija)",
    "Select categories..." : "Izbor kategorije ...",
    "Loading the task..." : "Poteka nalaganje naloge ...",
    "Task not found!" : "Naloge ni mogoče najti!",
    "add a subtask to" : "dodaj podrejeno nalogo"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-app-tasks-0.9.6-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/sl.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Naloge",
    "Due yesterday" : "Preteklo včeraj",
    "Due today" : "Preteče danes",
    "Due tomorrow" : "Preteče jutri",
    "Due on" : "Preteče",
    "Started yesterday" : "Začeto včeraj",
    "Starts today" : "Začne se danes",
    "Starts tomorrow" : "Začne se jutri",
    "Started on" : "Začeto",
    "Starts on" : "Začne se",
    "[Remind me yesterday at ]HH:mm" : "[Opomni me včeraj ob ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Opomni me danes ob ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Opomni me jutri ob ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Opomni me ]DD, MMM YYYY,[ ob ]HH:mm",
    "Yesterday" : "Včeraj",
    "Today" : "Danes",
    "Tomorrow" : "Jutri",
    "in %s" : "v %s",
    "%s ago" : "pred %s",
    "seconds" : "sekund",
    "a minute" : "minuta",
    "%d minutes" : "%d minut",
    "an hour" : "ura",
    "%d hours" : "%d ur",
    "a day" : "dan",
    "%d days" : "%d dni",
    "a month" : "mesec",
    "%d months" : "%d mesecev",
    "a year" : "leto",
    "%d years" : "%d let",
    "week" : "teden",
    "weeks" : "tednov",
    "day" : "dan",
    "days" : "dni",
    "hour" : "ura",
    "hours" : "ur",
    "minute" : "minuta",
    "minutes" : "minut",
    "second" : "drugi",
    "before beginning" : "pred začetkom",
    "after beginning" : "po začetku",
    "before end" : "pred koncem",
    "after end" : "po koncu",
    "Comment" : "Opomba",
    "Add a comment" : "Dodaj opombo",
    "This will delete the Calendar \"%s\" and all of its entries." : "Izbrisan bo koledar \"%s\" in vsi vpisani vnosi.",
    "The name \"%s\" is already used." : "Ime \"%s\" je že v uporabi.",
    "An empty name is not allowed." : "Prazno polje imena ni dovoljeno.",
    "Hidden" : "Skrito",
    "Visible" : "Vidno",
    "Automatic" : "Samodejno",
    "Sunday" : "nedelja",
    "Monday" : "ponedeljek",
    "Tuesday" : "torek",
    "Wednesday" : "sreda",
    "Thursday" : "četrtek",
    "Friday" : "petek",
    "Saturday" : "sobota",
    "Add an important item in \"%s\"..." : "Dodaj opomnik v \"%s\" ...",
    "Add an item due today in \"%s\"..." : "Dodaj opomnik, ki poteče danes v \"%s\" ...",
    "Add an item in \"%s\"..." : "Dodaj predmet v \"%s\" ...",
    "Add a current item in \"%s\"..." : "Dodaj trenutni predmet v \"%s\" ...",
    "Add a subtask to \"%s\"..." : "Dodaj podrejeno nalogo \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n končana naloga","%n končani nalogi","%n končane naloge","%n končanih nalog"],
    "Hours" : "Ure",
    "Minutes" : "Minute",
    "Set due date" : "Nastavi datum preteka",
    "%s %% completed" : "%s %% končano",
    "priority %s: " : "prednost %s: ",
    "high" : "visoka",
    "medium" : "srednja",
    "low" : "nizka",
    "no priority assigned" : "prednost ni določena",
    "Remind me" : "Opomni me",
    "at the end" : "na koncu",
    "at the beginning" : "na začetku",
    "Set start date" : "Nastavi datum začetka",
    "{calendar} shared by {owner}" : "{calendar} je objavila oseba {owner}",
    "Unnamed" : "Neimenovano",
    "Important" : "Pomembno",
    "Week" : "Teden",
    "All" : "Vsi",
    "Current" : "Trenutno",
    "Completed" : "Končano",
    "Delete" : "Izbriši",
    "Cancel" : "Prekliči",
    "Edit" : "Uredi",
    "Link" : "Povezava",
    "Download" : "Prejmi",
    "Save" : "Shrani",
    "Add List..." : "Dodaj seznam ...",
    "New List" : "Nov seznam",
    "Settings" : "Nastavitve",
    "Start of week" : "Začetek tedna",
    "Visibility of Smart Collections" : "Vidnost pametnih zbirk",
    "Change sort order" : "Spremeni vrstni red razvrščanja",
    "Default" : "Privzeto",
    "Due date" : "Datum zapadlosti",
    "Start date" : "Datum začetka",
    "Priority" : "Prednost",
    "Alphabetically" : "Abecedno",
    "Manually" : "Ročno",
    "Load remaining completed tasks." : "Naloži preostale končane naloge.",
    "Task is completed" : "Naloga je zaključena",
    "All day" : "Cel dan",
    "(New category)" : "(nova kategorija)",
    "Select categories..." : "Izbor kategorije ...",
    "Loading the task..." : "Poteka nalaganje naloge ...",
    "Task not found!" : "Naloge ni mogoče najti!",
    "add a subtask to" : "dodaj podrejeno nalogo",
    "Toggle subtasks" : "Preklopi podnaloge",
    "Toggle completed subtasks" : "Preklopi zaključene podnaloge"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
